@@ -37,11 +37,6 @@
             return(as.character(x[is.element(x, c("-", "dc"))]))
         }
     })))
-    if (!isTRUE(dots$no_column_info)) {
-        if (length(dc.code) > 1) {
-            stopError("Multiple \"don't care\" codes found.")
-        }
-    }
     fuzzy.cc <- logical(ncol(data))
     hastime <- logical(ncol(data))
     factor <- sapply(data, is.factor)
@@ -64,7 +59,7 @@
             if (!fuzzy.cc[i] & !anyNA(cc)) {
                 if (any(na.omit(cc) < 0)) {
                     hastime[i] <- TRUE
-                    cc[cc < 0] <- max(cc) + 1 
+                    cc[cc < 0] <- max(cc) + 1
                 }
             }
             if (declared[i]) {
